@@ -3,7 +3,9 @@ from .caltechdata import get_caltechdata, get_cd_github, get_history
 from .caltechfeeds import get_caltechfeed
 from .caltechfeeds import get_records
 from .datacite import get_datacite_codemeta, get_datacite_dois
+from .orcid import get_orcid_works
 from .github import get_github_id
 from .usage import get_usage, file_mapping, build_usage
 from .usage import aggregate_usage, build_aggregate
 from .eputil import get_eprint_keys, get_eprints, get_eprint
+from .eprints_extended import doi_in_authors, get_extended
